#Step 1: set working directory
library(tidyverse)
library(NHANES)
#additional library for statistic tests
library(lme4) # Package that provides multilevel modeling with lmer()
library(lmerTest) # Used to estimate degrees of freedom for LMER, 
library(emmeans) #for post hoc test with lmer


# Part I Hypothesis testing------------------------------------------------------------------

#load data used for hypothesis testing
load("DataUsedForHypothesisTesting.rda")
#plot data to ensure normal distribution
plot(density(full_dataset$value)) 
qqnorm(full_dataset$value); qqline(full_dataset$value)
ggplot(full_dataset, aes(x=value)) + geom_histogram()
#as data is not normally distributed, use log value
plot(density(full_dataset$log_value)) 
qqnorm(full_dataset$log_value); qqline(full_dataset$log_value)
ggplot(full_dataset, aes(x=log_value)) + geom_histogram()

# divide data into two windows --------------------------------------------

mm_window <- full_dataset %>%
  filter(time_window == "200-400ms") 

long_late_window <- full_dataset %>%
  filter(time_window == "800-1000ms") 


#model 1: influence of local rule on time window between 200-400ms
#usage of lme4 package to generate multi linear model - model allows to take into account subject ID
#usage of lmer as lme4 is the more recent function for MLM in R
mm.model <-
  lmer(
    log_value ~ local_rule + global_rule + local_rule*global_rule + (1|ID),
    data = long_late_window,
    na.action = "na.exclude"
  )


summary(mm.model)
anova(mm.model, type = "II") #anova to test significances within model
#plot of model residuals to see their distribution
res.mm.model = residuals(mm.model)
plot(res.mm.model)
qqnorm(res.mm.model)
qqline(res.mm.model)

#model for individual conditions to do post-hoc testing 
mm.model2 <-
  lmer(
    log_value ~ condition + (1|ID),
    data = mm_window,
    na.action = "na.exclude"
  )
anova(mm.model2, type = "II")
#post hoc test with estimated marginal means
emmeans(mm.model2, list(pairwise ~ condition), lmer.df = "satterthwaite", adjust = "fdr")

#model to check for interaction with global rule
mm.model3 <-
  lmer(
    log_value ~ local_rule + (1|ID) + global_rule + local_rule*global_rule,
    data = mm_window,
    na.action = "na.exclude"
  )

anova(mm.model3, type = "II") #anova to test significances within model

#model2: influence of global rule on late time window
long.late.model <-
  lmer(
    log_value ~  (1|ID) +global_rule,
    data = long_late_window,
    na.action = "na.exclude"
  )


summary(long.late.model)
anova(long.late.model, type = "II")

res.long.late.model = residuals(long.late.model)
plot(res.long.late.model)
qqnorm(res.long.late.model)
qqline(res.long.late.model)

# Example plot ------------------------------------------------------------
level_order1 <-   c('local_standard',
                   'local_deviant')

mm_window %>%
  ggplot(aes(
    x=factor(local_rule, level=level_order1), 
    y = value,
    color = local_rule,
    fill = local_rule
  )) + # + sign to continue plot
  geom_boxplot(alpha = 0.65) +
  xlab("Mismatch time window (200-400ms)") +
  ylab("Mean magnetic field strength in tesla") +
  theme_test() +
  theme(
    text = element_text(size = 22),
    axis.text.x = element_blank(),
    axis.ticks.x = element_blank(),
    legend.title = element_blank(),
    axis.text.y = element_text(size = 14),
    axis.title.x = element_text(size = 14, face = "bold"),
    axis.title.y = element_text(size = 14, face = "bold"),
    legend.text = element_text(size = 14)
  ) +

  scale_color_manual(values = c("#00CC00","#A6B399")) + #+
  scale_fill_manual(values = c("#00CC00" ,"#A6B399")) #local standard + local deviant


# Part II Exploratory analysis --------------------------------------------
# time windows for explorative analysis represent significant time windows detected by permutation testing in Matlab previously

load("DatasetExploratoryAnalysis.rda")

#exclude all participants, with only one recording block -> N=15 in "full_dataset_within"
full_dataset_within <- full_dataset %>% 
  filter(ID !=7, ID!=9,ID!=27,ID!=47,ID!=48)
#the following analysis only use the N=15 particiants with both recording blocks

# check for normality -----------------------------------------------------

plot(density(full_dataset_within$value)) 
qqnorm(full_dataset_within$value); qqline(full_dataset_within$value)
ggplot(full_dataset_within, aes(x=value)) + geom_histogram()

plot(density(full_dataset_within$log_value)) 
qqnorm(full_dataset_within$log_value); qqline(full_dataset_within$log_value)
ggplot(full_dataset_within, aes(x=log_value)) + geom_histogram()

# Create individual datasets for each time window

early_window <- full_dataset_within %>%
  filter(time_window == "080-115ms")

late_window <- full_dataset_within %>%
  filter(time_window == "720-745ms")


# MLM ---------------------------------------------------------------------

# model for early time window to check influence of local rule
early.model <-
  lmer(
    log_value ~ global_rule + (1|ID) + local_rule + global_rule*local_rule,
    data = early_window,
    na.action = "na.exclude"
  )

summary(early.model)
anova(early.model, type = "II") # anova on significant effects within model
#attempt to look at distributio of residuals
res.early.model = residuals(early.model)
plot(res.early.model)
qqnorm(res.early.model)
qqline(res.early.model)

#additional model to do post hoc test on individual conditions
early.model2 <-
  lmer(
    log_value ~ condition + (1|ID),
    data = early_window,
    na.action = "na.exclude"
  )

#post hoc test of individual conditions
emmeans(early.model2, list(pairwise ~ condition), lmer.df = "satterthwaite", adjust = "no")



#model for late time window to check influence of local rule
late.model <-
  lmer(
    log_value ~ global_rule + (1|ID) + local_rule + global_rule*local_rule,
    data = late_window,
    na.action = "na.exclude"
  )

summary(late.model)
anova(late.model, type = "II")
res.late.model = residuals(late.model)
plot(res.late.model)
qqnorm(res.late.model)
qqline(res.late.model)

late.model2 <-
  lmer(
    log_value ~ condition + (1|ID),
    data = late_window,
    na.action = "na.exclude"
  )
emmeans(late.model2, list(pairwise ~ condition), lmer.df = "satterthwaite", adjust = "no")



# Exploratory analysis including HRV --------------------------------------
#dataset contains classification of SDNN values in 'high' (upper third) 'middle' and 'low' (lower third) HRV

#plot to show HRV groups
late_window %>%
  ggplot(aes(
    x = ID,
    y = hrv_vec,
    color = HRV,
    shape=HRV,
    group = HRV
  )) + 
  geom_point(size=3.5)+
  xlab("participant ID") +
  ylab("heart rate variability") +
  theme_test() +
  theme(
    text = element_text(size = 22),
    legend.title = element_blank(),
    axis.text.y = element_text(size = 14),
    axis.title.x = element_text(size = 14, face = "bold"),
    axis.title.y = element_text(size = 14, face = "bold"),
    legend.text = element_text(size = 14)
  ) +
  facet_grid(cols = vars(stim_block)) +
  
  scale_color_manual(values = c("#000000", "#8C8B8B", "#000000"))  +
scale_shape_manual(values = c(16,15, 13))  #+

# MLM with HRV as covariate -----------------------------------------------

# create datasets with only the high and low hrv subjects to have exteme groups for analysis
early_window_hrv <- early_window %>% 
  filter(HRV != "middle HRV") #exclusion of middle HRV

late_window_hrv <- late_window %>% 
  filter(HRV != "middle HRV")

# Multilinear Model including high and low HRV values
#test for interaction between HRV group and global rule
iHRV.model <-
  lmer(
    log_value ~  (1|ID) +global_rule +HRV +  HRV *global_rule,
    data =late_window_hrv,
    na.action = "na.exclude"
  )

anova(iHRV.model, type = "II")
res.iHRV.model = residuals(iHRV.model)
plot(res.iHRV.model)
qqnorm(res.iHRV.model)
qqline(res.iHRV.model)

#seperate by conditions to do post hoc test on differences between individual conditions
iHRVc.model <-
  lmer(
    log_value ~  (1|ID) +condition +HRV +  HRV *condition,
    data =late_window_hrv,
    na.action = "na.exclude"
  )

anova(iHRVc.model, type = "II")
emmeans(iHRVc.model, list(pairwise ~ condition*HRV), lmer.df = "satterthwaite", adjust = "no")


# Example for Boxplot -------------------------------------------------------------------

level_order <-   c('a_standard',
                   'global_deviant',
                   'local_deviant',
                   'local_and_global_deviant')

late_window_hrv %>%
  ggplot(aes(
    x = factor(condition, level = level_order),
    y = value,
    color = condition,
    fill = condition )) + 
  geom_boxplot(alpha = 0.65) +
  xlab("") +
  ylab("Mean magnetic field strength in tesla") +
  theme_test() +
  theme(
    text = element_text(size = 22),
    axis.text.x = element_blank(),
    axis.ticks.x = element_blank(),
    legend.title = element_blank(),
    axis.text.y = element_text(size = 14),
    axis.title.x = element_text(size = 14, face = "bold"),
    axis.title.y = element_text(size = 14, face = "bold"),
    legend.text = element_text(size = 14)
  ) +
  facet_grid(cols = vars(HRV)) +
  scale_color_manual(values = c("#1A1ACC","#FF991A","#E6001A","#00B3CC")) + #+
  scale_fill_manual(values = c("#1A1ACC","#FF991A","#E6001A","#00B3CC"  )) #standard, global, local, local and global



level_order <-   c('global_standard',
                   'global_deviant')

late_window_hrv %>%
  ggplot(aes(
    x = factor(global_rule, level = level_order),
    y = value,
    color = global_rule,
    fill = global_rule )) +
  geom_boxplot(alpha = 0.65) +
  xlab("") +
  ylab("Mean magnetic field strength in tesla") +
  theme_test() +
  theme(
    text = element_text(size = 22),
    axis.text.x = element_blank(),
    axis.ticks.x = element_blank(),
    legend.title = element_blank(),
    axis.text.y = element_text(size = 14),
    axis.title.x = element_text(size = 14, face = "bold"),
    axis.title.y = element_text(size = 14, face = "bold"),
    legend.text = element_text(size = 14)
  ) +
  facet_grid(cols = vars(HRV)) +
scale_color_manual(values = c("#990099", "#998099")) + #+
scale_fill_manual(values = c("#990099", "#998099" )) #global standard + global deviant


# Correlation HRV, differences ----------------------------------------
# this analysis calculates correlations within one recording block. therefore all N=20 participants will be included
# A "new" late window is definded with the "full_dataset"
late_window_new <- full_dataset %>%
  filter(time_window == "720-745ms")
#seperate variables from dataframe to perform correlation analysis
data_glob_dev <-late_window_new %>% 
  filter(condition=="global_deviant") 
data_loc_dev <- late_window_new %>% 
  filter(condition=="local_deviant") 
data_loc_glob_dev <-late_window_new %>% 
  filter(condition=="local_and_global_deviant") 
data_std <- late_window_new %>% 
  filter(condition=="a_standard") 

#hrv values for each recording block (Block A= std & local  and global; Block B= local dev + global dev)
hrv_val_blockA <- data_std$hrv_vec
hrv_val_blockB <- data_glob_dev$hrv_vec

#differences between global deviant and global standard in each block
diff_meg_blockA <- data_loc_glob_dev$value - data_std$value
diff_meg_blockB <- data_glob_dev$value - data_loc_dev$value

#correlation test. Default=Pearson correlation
cor.test(diff_meg_blockA, hrv_val_blockA)
cor.test(diff_meg_blockB, hrv_val_blockB)

